#
# spec file for package openscad
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openscad
Version:        2021.01
Release:        6.2
Summary:        Programmers Solid 3D CAD Modeller
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/CAD
URL:            https://www.openscad.org/
Source:         https://files.openscad.org/%{name}-%{version}.src.tar.gz
Patch0:         fix_build_with_cgal-5.3.patch
Patch1:         CVE-2022-0496.patch
Patch2:         CVE-2022-0497.patch
Patch3:         fix_build_with_cgal-5.4.patch
Patch4:         fix_build_issue_with_overloaded_join.patch
Patch5:         fix_fs_error.patch
BuildRequires:  bison
BuildRequires:  double-conversion-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_thread-devel
# Upstream has dropped pre-cgal-5.0 support and with that, reworked
# CGAL integration fully.
# Backporting relevant patches does not make sense.
BuildRequires:  libcgal-devel > 5.0
BuildRequires:  libqscintilla-qt5-devel
BuildRequires:  libspnav-devel
BuildRequires:  memory-constraints
BuildRequires:  opencsg-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gamepad)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(cairo) > 1.14
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
# With v2019.05, openGL is required but Arm uses openGL ES
ExcludeArch:    %{arm} aarch64

%description
OpenSCAD is a software for creating solid 3D CAD objects. It does not
focus on the artistic aspects of 3D modelling and does not target the
creation of, say, computer-animated movies, but instead on the CAD
aspects, e.g. modelling of machine parts.

%prep
%autosetup -p1

%build
%qmake5 PREFIX=%{_prefix} CONFIG+=qopenglwidget

# As of 08.05.2021, memoryperjob constraint is not working correctly,
# so limit memory per job here.
%limit_build -m 2500
%make_build

%install
%qmake5_install

install -D -m 0644 doc/openscad.1 %{buildroot}%{_mandir}/man1/openscad.1

# remove bundled liberation fonts
rm -r %{buildroot}%{_datadir}/openscad/fonts

%find_lang %{name}

rm %{buildroot}%{_datadir}/openscad/libraries/MCAD/.gitignore

%files -f %{name}.lang
%dir %{_datadir}/metainfo

%doc README.md doc/*.pdf
%license COPYING

%{_bindir}/openscad
%{_datadir}/applications/openscad.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/org.openscad.OpenSCAD.appdata.xml
%{_datadir}/mime/packages/openscad.xml
%{_datadir}/openscad/
%{_mandir}/man1/*

%changelog
* Mon May 27 2024 George <georgewoodall82@gmail.com>
- Add patch to fix is_regular is not a member of fs
  + fix_fs_error.patch
* Mon Jul  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Rebase fix_build_with_cgal-5.4.patch
- Spec cleanup
* Sun Apr  3 2022 Samu Voutilainen <smar@smar.fi>
- Disable build with GCAL-5.4 or newer.
  Upstream has dropped pre-cgal-5.0 support and with that, reworked
  CGAL integration fully. Backporting relevant patches does not
  make sense.
- Add patch to fix compilation with CGAL-5.4
  + fix_build_with_cgal-5.4.patch
- Add patch to fix compilation with newer Boost versions
  + fix_build_issue_with_overloaded_join.patch
* Sun Feb  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to fix out-of-bounds memory access in DXF loader
  + CVE-2022-0496.patch (boo#1195568, CVE-2022-0496)
- Add patch to fix out-of-bounds memory access in comment parser
  + CVE-2022-0497.patch (boo#1195567, CVE-2022-0497)
* Fri Aug 27 2021 Samu Voutilainen <smar@smar.fi>
- Added patch fix_build_with_cgal-5.3.patch.
  Upstream patch to fix build with CGAL-5.3.
* Sat May  8 2021 Samu Voutilainen <smar@smar.fi>
- Reintroduce memory-contraints macro %%limit_build -m 2500.
  Constraint memoryperjob is allowing too small workers for
  the jobs it provides.
* Thu May  6 2021 Samu Voutilainen <smar@smar.fi>
- Increased memoryperjob constraint to 2500 MB.
* Tue Apr 20 2021 Samu Voutilainen <smar@smar.fi>
- Update to 2021.1 release
  + Language Features
  * New
    Add function literals
    Add exponent function (e.g. 2^3)
    Add convexity parameter to resize()
    Add support for generic tail recursion
    Add $vpf for viewport field of view
    Add warnings for ranges with begin < end
    Add warnings for matrix structure problems
  * Changed
    Allow random seeds to stick between rands() calls
    Make comparison operators on mixed types return undef
    Track reason for values turning undef
  * Fixed
    Fix Range precision
    Fix empty geometry handling
    Fix search order for imported modules
    Improve internal handling of data values
    Improve performance of array concatenation
    Improve float accuracy of mirror matrix calculation
    Improve polygon and polyhedron warnings/errors
  + Program Features
  * GUI
    Add jump to source code from 3D preview
    Add Error-Log window for tracking errors and warnings
    Add window menu to allow keyboard access to all docked windows
    Enable default binary stl output, and ascii option
    Show message in console when caches are flushed
    Disable HTML rendering in console
    Enable color scheme for CGAL 2D render
    Simplified OpenCSG edge shader, with added smoothing
    New and updated translations: Chinese, Armenian, French, Russian, Polish, German
  * Editor
    Edit multiple files in tabs
    Switch tabs via Ctrl+Tab / Ctrl+Shift+Tab
    Modify numbers via mouse scroll (when holding ALT)
    Add auto-complete & call-tips for built-ins
    Add configurable code snippets
    Add (line) bookmarks
    Add jump to error
    Add support for line/block copy and move
    Add convenience context menu to tab header
    Open include<>/use<> files via inline link
    Fix search highlight for utf8 text
    Fix display of matches in search field
    Add Find/Find Next/Find Previous to editor context menu
  * Command line
    Support reading scripts from STDIN
    Support export to STDOUT
    Add multi-export on command line
    Add --animate command line option
    Add --export-format command line option
    Allow view-port variables in command-line mode
    Allow export to .ast, .csg, .echo and .term in preview mode
    Print statistics in cmdline mode as in GUI
  * General
    Add PDF export (single page only)
    Add support for line-cap and line-join in SVG import
    Add support stroke-linejoin in SVG import
    Change CGAL Union to join least complex geometries first
    Install start shortcut for all users on Windows
    Install icons with defined sizes (e.g. required by flathub)
    Switch to C++14 and allow usage of header-only CGAL
    Add support for lib3MF v2.0 API
    Update AppStream release info
- Ran spec through spec-cleaner
- removed boost_include.diff (upstream)
* Tue Oct  6 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- openGL is required but Arm uses openGL ES, so exclude %%arm
  and aarch64
* Fri Oct  2 2020 Dirk Stoecker <opensuse@dstoecker.de>
- fix build with new C++ compilers, add boost_include.diff
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Sun Mar 22 2020 Christophe Giboudeaux <christophe@krop.fr>
- Explicitly require libboost_thread-devel for building openscad.
* Mon Jun 24 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2019.05 release
  + Language Features:
  * New modules
    assert() - stop script evaluation on failed constraints
    let() - scoped assignment
  * New functions
    ord() - convert from character to Unicode code point
    echo()
    assert() - stop script evaluation on failed constraints
    Type testing functions: is_undef(), is_list(), is_num(), is_bool(), is_string()
  * New special variable: $preview variable which is set to true in preview mode
  * List comprehension updates
    Added if/else condition
    Added each keyword
    Added C-style for loop
    Now allows looping over characters of a string
  * rotate_extrude(): Added angle parameter to
  * import() now supports SVG, 3MF and AMF
  * color() now supports hex color codes
  * Removed glide() and subdiv() which were never implemented
  + Program Features:
  * Customizer: Allow parametrizing design parameters with GUI customization
  * Support for using 3D-Mouse / Joystick / Gamepad input devices for controlling the 3D view
  * 3D Printing support: Purchase from a print service partner or print to Octoprint
  * New export file formats: SVG, 3MF, AMF
  * Quick-edit and preview of values using Alt-Arrows (Shift-Alt-Arrows on macOS)
  * Added --view cmd-line parameter
  * Play sound notification on render complete
  * Line numbers and filenames are now shown for many errors and warnings
  * Hardwarning preference: Stop on first warning
  * Hardwarning and assert now shows a stack trace
  * New warnings
    Module call parameterns don't match module declaration
    Argument value of of range
    Duplicate passed argument
    Children passed to module not accepting children
    Reference to inknown $special_variables
    Duplicate assigment
  * New translations: Ukrainian, Polish
- Updated BuildRequires:
  - Drop glew-devel and some boost headers
  - Add libspnav for 3D mouse, Qt5Multimedia for notifications
- Cleanup spec file, remove conditionals for Fedora (still targeting EOLed Qt4)
- Drop upstream patches:
  openscad-git4fa5f0340a.patch
  openscad-git_c68684f9520d.patch
* Wed Mar 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup BuildRequires, sort, remove duplicates
- Fix Url:, openscad.org redirects to www.openscad.org
- Add openscad-git_c68684f9520d.patch, fix build with Boost 1.69
- Use %%license, remove %%defattr
* Fri Dec 15 2017 plinnell@opensuse.org
- Fix the BuildRequires to fix build on Factory/TW
* Tue Jun 13 2017 idonmez@suse.com
- Change license to GPL-3.0+, see
  https://github.com/openscad/openscad/issues/2059
* Thu Apr 27 2017 jengelh@inai.de
- Remove useless %%clean section
- Trim description
* Sun Jan 15 2017 herbert@graeber-clan.de
- Add patch openscad-git4fa5f0340a.patch from upstream, to fix
  build with newer Qt5 and gcc versions
* Thu Dec 22 2016 herbert@graeber-clan.de
- Switch to Qt5
* Thu Nov 19 2015 prusnak@opensuse.org
- updated to 2015.03-2
* Tue Apr 21 2015 prusnak@opensuse.org
- updated to 2015.03-1
* Wed Mar 11 2015 prusnak@opensuse.org
- updated to 2015.03
* Mon Mar 10 2014 prusnak@opensuse.org
- updated to 2014.03
* Wed Jun 19 2013 prusnak@opensuse.org
- updated to 2013.06
* Sat Jan 19 2013 prusnak@opensuse.org
- updated to 2013.01
* Fri Nov 23 2012 prusnak@opensuse.org
- fix build (glu.patch)
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 2011.12
* Wed Sep  7 2011 prusnak@opensuse.org
- updated to 2011.06
* Fri May 13 2011 prusnak@opensuse.org
- updated to 2011.04
* Wed Oct 13 2010 prusnak@opensuse.org
- created package (2010.05)
